.. Copyright (C) 2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.libvirtd_qemu`` role manages the QEMU configuration used by the
libvirt daemon. It is a part of the :ref:`debops.libvirtd`, separated to
allow easier configuration maintenance.
